@@ -16,7 +16,7 @@ openFreePort = bracket (socket AF_INET Stream defaultProtocol) close $ \s -> do
   localhost <- inet_addr "127.0.0.1"
   bind s (SockAddrInet aNY_PORT localhost)
   listen s 1
-  fromIntegral <$> socketPort s
+  fmap fromIntegral $ socketPort s
 
 waitForDB :: FilePath -> Int -> IO ()
 waitForDB mainDir port
@@ -133,8 +133,8 @@ startWithLogger logger options mainDir stdOut stdErr = try $ flip onException (r
   let dataDir = mainDir ++ "/data"
 
   logger InitDB
-  initDBExitCode <- runProcessWith stdOut stdErr "initDB"
-      ("initDB --nosync -E UNICODE -A trust -D " ++ dataDir)
+  initDBExitCode <- runProcessWith stdOut stdErr "initdb"
+      ("initdb --nosync -E UNICODE -A trust -D " ++ dataDir)
   throwIfError InitDBFailed initDBExitCode
 
   logger WriteConfig
@@ -191,4 +191,4 @@ stop DB {..} = do
   terminateProcess pid
   result <- waitForProcess pid
   removeDirectoryRecursive mainDir
-  return result
\ No newline at end of file
+  return result
